edcert_compressor::certificate_loader

Struct CertificateLoader

pub struct CertificateLoader;
This type can be used to load Certificates.

Implementations

Source

impl CertificateLoader

pub fn save_to_folder( cert: &Certificate, folder: &str, ) -> Result<(), &'static str>

Saves this certificate into a folder: one file for the certificate and one file for the private key.

pub fn load_from_folder(folder: &str) -> Result<Certificate, &'static str>

Reads a certificate from a folder like it has been saved with save_to_folder

pub fn save_to_file( cert: &Certificate, filename: &str, ) -> Result<(), &'static str>

Saves the certificate in encoded form to a file

pub fn save_private_key( cert: &Certificate, filename: &str, ) -> Result<(), &'static str>

Saves the private key to a file. Just the binary string.

pub fn load_from_file(filename: &str) -> Result<Certificate, &'static str>

This method loads a certificate from a file.

pub fn load_private_key( cert: &mut Certificate, filename: &str, ) -> Result<(), &'static str>

This method reads a private key from a file and sets it in this certificate.